0.0.1
=====
* rename project to 'jiraprompt', initial release to pypi

0.0.2
=====
* bug fix for timezone not always being printed in worklogs

0.0.3
=====
* bug fix for update check not displaying versions properly

0.0.4
=====
* bug fix when creating new card with sprint='backlog'

0.0.5
=====
* compatibility fixes for cmd2 0.8.3
